searchData={"items":[{"type":"module","title":"DSMR","doc":"A library for parsing Dutch Smart Meter Requirements (DSMR) telegram data.","ref":"DSMR.html"},{"type":"module","title":"Usage - DSMR","doc":"```elixir\ntelegram =\n  # String is formatted in separate lines for readability.\n  Enum.join([\n    \"/KFM5KAIFA-METER\\r\\n\",\n    \"\\r\\n\",\n    \"1-3:0.2.8(42)\\r\\n\",\n    \"0-0:1.0.0(161113205757W)\\r\\n\",\n    \"0-0:96.1.1(3960221976967177082151037881335713)\\r\\n\",\n    \"1-0:1.8.1(001581.123*kWh)\\r\\n\",\n    \"1-0:1.8.2(001435.706*kWh)\\r\\n\",\n    \"1-0:2.8.1(000000.000*kWh)\\r\\n\",\n    \"1-0:2.8.2(000000.000*kWh)\\r\\n\",\n    \"0-0:96.14.0(0002)\\r\\n\",\n    \"1-0:1.7.0(02.027*kW)\\r\\n\",\n    \"1-0:2.7.0(00.000*kW)\\r\\n\",\n    \"0-0:96.7.21(00015)\\r\\n\",\n    \"0-0:96.7.9(00007)\\r\\n\",\n    \"1-0:99.97.0(3)(0-0:96.7.19)(000104180320W)(0000237126*s)(000101000001W)\",\n    \"(2147583646*s)(000102000003W)(2317482647*s)\\r\\n\",\n    \"1-0:32.32.0(00000)\\r\\n\",\n    \"1-0:52.32.0(00000)\\r\\n\",\n    \"1-0:72.32.0(00000)\\r\\n\",\n    \"1-0:32.36.0(00000)\\r\\n\",\n    \"1-0:52.36.0(00000)\\r\\n\",\n    \"1-0:72.36.0(00000)\\r\\n\",\n    \"0-0:96.13.1()\\r\\n\",\n    \"0-0:96.13.0()\\r\\n\",\n    \"1-0:31.7.0(000*A)\\r\\n\",\n    \"1-0:51.7.0(006*A)\\r\\n\",\n    \"1-0:71.7.0(002*A)\\r\\n\",\n    \"1-0:21.7.0(00.170*kW)\\r\\n\",\n    \"1-0:22.7.0(00.000*kW)\\r\\n\",\n    \"1-0:41.7.0(01.247*kW)\\r\\n\",\n    \"1-0:42.7.0(00.000*kW)\\r\\n\",\n    \"1-0:61.7.0(00.209*kW)\\r\\n\",\n    \"1-0:62.7.0(00.000*kW)\\r\\n\",\n    \"0-1:24.1.0(003)\\r\\n\",\n    \"0-1:96.1.0(4819243993373755377509728609491464)\\r\\n\",\n    \"0-1:24.2.1(161129200000W)(00981.443*m3)\\r\\n\",\n    \"!6796\\r\\n\"\n  ])\n\nDSMR.parse(telegram)\n#=> {:ok, %DSMR.Telegram{checksum: \"6796\", data: [{[1, 3, 0, 2 , 8], \"42\"}, ...]}\n```","ref":"DSMR.html#module-usage"},{"type":"function","title":"DSMR.parse/2","doc":"Parses telegram data from a string and returns a `DSMR.Telegram` struct.","ref":"DSMR.html#parse/2"},{"type":"function","title":"Options - DSMR.parse/2","doc":"* `:checksum` - when true, the checksum will be validated, defaults to `true`.\n\n  * `:floats` - controls how floats are parsed. Possible values are:\n\n    * `:native` (default) - Native conversion from binary to float using `:erlang.binary_to_float/1`,\n    * `:decimals` - uses `Decimal.new/1` to parse the binary into a Decimal struct with arbitrary precision.","ref":"DSMR.html#parse/2-options"},{"type":"function","title":"DSMR.parse!/2","doc":"Parses telegram data from a string and returns a `DSMR.Telegram` struct.\n\nSimilar to `parse/2` except it will unwrap the error tuple and raise\nin case of errors.","ref":"DSMR.html#parse!/2"},{"type":"type","title":"DSMR.parse_opt/0","doc":"","ref":"DSMR.html#t:parse_opt/0"},{"type":"module","title":"DSMR.Measurement","doc":"","ref":"DSMR.Measurement.html"},{"type":"type","title":"DSMR.Measurement.t/0","doc":"","ref":"DSMR.Measurement.html#t:t/0"},{"type":"module","title":"DSMR.Telegram","doc":"","ref":"DSMR.Telegram.html"},{"type":"type","title":"DSMR.Telegram.obis_t/0","doc":"","ref":"DSMR.Telegram.html#t:obis_t/0"},{"type":"type","title":"DSMR.Telegram.obj_t/0","doc":"","ref":"DSMR.Telegram.html#t:obj_t/0"},{"type":"type","title":"DSMR.Telegram.t/0","doc":"","ref":"DSMR.Telegram.html#t:t/0"},{"type":"type","title":"DSMR.Telegram.value_t/0","doc":"","ref":"DSMR.Telegram.html#t:value_t/0"},{"type":"module","title":"DSMR.Timestamp","doc":"","ref":"DSMR.Timestamp.html"},{"type":"type","title":"DSMR.Timestamp.t/0","doc":"","ref":"DSMR.Timestamp.html#t:t/0"},{"type":"exception","title":"DSMR.ChecksumError","doc":"","ref":"DSMR.ChecksumError.html"},{"type":"type","title":"DSMR.ChecksumError.t/0","doc":"","ref":"DSMR.ChecksumError.html#t:t/0"},{"type":"exception","title":"DSMR.ParseError","doc":"","ref":"DSMR.ParseError.html"},{"type":"type","title":"DSMR.ParseError.t/0","doc":"","ref":"DSMR.ParseError.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}